@@ -14,7 +14,7 @@ import (
 // (This function does not operate directly on a tengo.Schema alone, because the
 // original fs.LogicalSchema is also needed, in order to generate annotations
 // corresponding to SQL statements / files / line numbers.)
-func CheckSchema(wsSchema *workspace.Schema, opts Options) *Result {
+func CheckSchema(wsSchema *workspace.Schema, opts *Options) *Result {
 	result := &Result{}
 	objects := wsSchema.Objects()
 
@@ -44,26 +44,26 @@ func CheckSchema(wsSchema *workspace.Schema, opts Options) *Result {
 
 // ObjectChecker values may be used to check for problems in database objects.
 type ObjectChecker interface {
-	CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts Options) []Note
+	CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts *Options) []Note
 }
 
 // GenericChecker is a function that looks for problems in multiple types of
 // database objects. It can return any number of notes per object.
-type GenericChecker func(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts Options) []Note
+type GenericChecker func(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts *Options) []Note
 
 // CheckObject allows GenericChecker functions to satisfy the ObjectChecker
 // interface.
-func (c GenericChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts Options) []Note {
+func (c GenericChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts *Options) []Note {
 	return c(object, createStatement, schema, opts)
 }
 
 // TableChecker is a function that looks for problems in a table. It can return
 // any number of notes per table.
-type TableChecker func(table *tengo.Table, createStatement string, schema *tengo.Schema, opts Options) []Note
+type TableChecker func(table *tengo.Table, createStatement string, schema *tengo.Schema, opts *Options) []Note
 
 // CheckObject provides arg conversion in order for TableChecker functions to
 // satisfy the ObjectChecker interface.
-func (tc TableChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts Options) []Note {
+func (tc TableChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts *Options) []Note {
 	if table, ok := object.(*tengo.Table); ok {
 		return tc(table, createStatement, schema, opts)
 	}
@@ -72,11 +72,11 @@ func (tc TableChecker) CheckObject(object tengo.DefKeyer, createStatement string
 
 // TableBinaryChecker is like a TableChecker that returns at most a single Note
 // per table.
-type TableBinaryChecker func(table *tengo.Table, createStatement string, schema *tengo.Schema, opts Options) *Note
+type TableBinaryChecker func(table *tengo.Table, createStatement string, schema *tengo.Schema, opts *Options) *Note
 
 // CheckObject provides arg and return conversion in order for
 // TableBinaryChecker functions to satisfy the ObjectChecker interface.
-func (tbc TableBinaryChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts Options) []Note {
+func (tbc TableBinaryChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts *Options) []Note {
 	if table, ok := object.(*tengo.Table); ok {
 		if note := tbc(table, createStatement, schema, opts); note != nil {
 			return []Note{*note}
@@ -89,11 +89,11 @@ func (tbc TableBinaryChecker) CheckObject(object tengo.DefKeyer, createStatement
 // or function. Routine checks are always strictly binary; in other words, for
 // each routine, either a single note is found (non-nil return), or no note is
 // found (nil return).
-type RoutineChecker func(routine *tengo.Routine, createStatement string, schema *tengo.Schema, opts Options) *Note
+type RoutineChecker func(routine *tengo.Routine, createStatement string, schema *tengo.Schema, opts *Options) *Note
 
 // CheckObject provides arg conversion in order for RoutineChecker functions to
 // satisfy the ObjectChecker interface.
-func (rc RoutineChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts Options) []Note {
+func (rc RoutineChecker) CheckObject(object tengo.DefKeyer, createStatement string, schema *tengo.Schema, opts *Options) []Note {
 	if routine, ok := object.(*tengo.Routine); ok {
 		if note := rc(routine, createStatement, schema, opts); note != nil {
 			return []Note{*note}
