@@ -82,7 +82,7 @@ type DockerizedInstanceOptions struct {
 
 	// Options that only affect new container creation:
 	DataBindMount       string // Host path to bind-mount as /var/lib/mysql in container
-	DataTmpfs           bool   // Use tmpfs for /var/lib/mysql. Only used if DataBindMount == "" && runtime.GOOS == "linux"
+	DataTmpfs           bool   // Use tmpfs for /var/lib/mysql. Only used if no DataBindMount, runtime.GOOS is Linux, and image is from a top-level repo (e.g. "foo" but not "foo/bar")
 	EnableBinlog        bool   // Enable or disable binary log in database server
 	LowerCaseTableNames uint8  // lower_case_table_names setting (0, 1, or 2) in database server
 }
@@ -123,7 +123,11 @@ func CreateDockerizedInstance(opts DockerizedInstanceOptions) (*DockerizedInstan
 	}
 	if opts.DataBindMount != "" {
 		dflags = append(dflags, "-v {DATABINDMOUNT}")
-	} else if opts.DataTmpfs && runtime.GOOS == "linux" {
+	} else if opts.DataTmpfs && runtime.GOOS == "linux" && !strings.ContainsRune(opts.Image, '/') {
+		// tmpfs can only be used on *native* Linux (not Docker Desktop for Mac/Win).
+		// It can also cause permission issues with some non-Docker-official images,
+		// such as percona/percona-server; for this reason we only enable it for
+		// images from the top-level namespace, since these are known to support it.
 		dflags = append(dflags, "--tmpfs /var/lib/mysql")
 	}
 	flagString := strings.Join(dflags, " ")
@@ -137,6 +141,7 @@ func CreateDockerizedInstance(opts DockerizedInstanceOptions) (*DockerizedInstan
 		"--performance-schema=0",                // disable performance_schema to reduce memory usage and other overhead
 		"--skip-innodb-adaptive-hash-index",     // AHI not beneficial to DDL-based workload
 		"--loose-innodb-log-writer-threads=off", // log writer threads harm workspace perf (loose- prefix since only in MySQL 8.0.22+)
+		"--loose-query-cache-size=0",            // ensure query cache completely disabled (loose- prefix since no longer in MySQL 8+)
 	}
 	if opts.EnableBinlog {
 		serverArgs = append(serverArgs, "--log-bin", "--server-id=1")
@@ -194,7 +199,7 @@ func GetDockerizedInstance(opts DockerizedInstanceOptions) (*DockerizedInstance,
 	// check intentionally ignores point release numbers.
 	if opts.Image != "" {
 		adjustedImage := simplifiedImageName(opts.Image)
-		if imageFlavor := ParseFlavor(adjustedImage); imageFlavor.Supported() && imageFlavor.Family() != di.Flavor().Family() {
+		if imageFlavor := ParseFlavor(adjustedImage); imageFlavor.Known() && imageFlavor.Family() != di.Flavor().Family() {
 			return nil, fmt.Errorf("Container %s based on unexpected flavor: expected %s, found %s", opts.Name, imageFlavor.Family(), di.Flavor().Family())
 		}
 	}
@@ -226,6 +231,13 @@ func newDockerizedInstance(opts DockerizedInstanceOptions) (*DockerizedInstance,
 	}
 
 	if err := di.TryConnect(); err != nil {
+		vars := map[string]string{
+			"NAME": opts.Name,
+		}
+		s := shellout.New("docker logs --tail 100 {NAME}").WithVariablesStrict(vars)
+		if logs, logErr := s.RunCaptureCombined(); logErr == nil {
+			err = fmt.Errorf("%w\nLast 100 lines of container logs:\n%s", err, logs)
+		}
 		return nil, err
 	}
 	return di, nil
@@ -474,7 +486,7 @@ func (di *DockerizedInstance) SourceSQL(filePaths ...string) (string, error) {
 	}
 	combinedInput := io.MultiReader(readers...)
 	cmd := []string{"mysql", "-tvvv", "-u", "root", "-h", "127.0.0.1", "--default-character-set", "utf8mb4"}
-	if di.Flavor().Min(FlavorMariaDB110) {
+	if di.Flavor().MinMariaDB(11, 0) {
 		cmd[0] = "mariadb" // MariaDB 11.0+ images don't include `mysql` symlink
 	}
 	stdoutStr, stderrStr, err := di.Exec(cmd, combinedInput)
@@ -539,6 +551,10 @@ func simplifiedImageName(image string) string {
 		}
 	}
 	if hasTag {
+		tag, _, _ = strings.Cut(tag, "-") // discard any suffix like "-aarch64"
+		if strings.Count(tag, ".") > 1 && strings.HasSuffix(tag, ".0") {
+			tag = tag[0 : len(tag)-2] // discard any ".0" point release, e.g. "8.1.0" becomes "8.1"
+		}
 		return base + ":" + tag
 	}
 	return base
@@ -564,7 +580,7 @@ func (fl filteredLogger) Print(v ...interface{}) {
 			}
 		}
 	}
-	fl.logger.Print(v...)
+	fl.logger.Output(2, fmt.Sprint(v...))
 }
 
 // UseFilteredDriverLogger overrides the mysql driver's logger to avoid excessive
