@@ -94,7 +94,12 @@ func (instance *Instance) String() string {
 	}
 }
 
-func (instance *Instance) buildParamString(params string) string {
+// BuildParamString returns a DB connection parameter string, which first takes
+// the instance's default params and then applies overrides on top.
+// The arg should be a URL query string formatted value, for example
+// "foo=bar&fizz=buzz" to apply foo=bar and fizz=buzz on top of any instance
+// default parameters.
+func (instance *Instance) BuildParamString(params string) string {
 	v := url.Values{}
 	for defName, defValue := range instance.defaultParams {
 		v.Set(defName, defValue)
@@ -116,7 +121,7 @@ func (instance *Instance) buildParamString(params string) string {
 // The connection pool's max size, max conn lifetime, and max idle time are all
 // tuned automatically to intelligent defaults based on auto-discovered limits.
 func (instance *Instance) ConnectionPool(defaultSchema, params string) (*sqlx.DB, error) {
-	fullParams := instance.buildParamString(params)
+	fullParams := instance.BuildParamString(params)
 	return instance.rawConnectionPool(defaultSchema, fullParams, false)
 }
 
@@ -125,7 +130,7 @@ func (instance *Instance) ConnectionPool(defaultSchema, params string) (*sqlx.DB
 // combination of defaultSchema and params, a pre-existing connection pool will
 // be returned. See ConnectionPool for usage of the args for this method.
 func (instance *Instance) CachedConnectionPool(defaultSchema, params string) (*sqlx.DB, error) {
-	fullParams := instance.buildParamString(params)
+	fullParams := instance.BuildParamString(params)
 	key := fmt.Sprintf("%s?%s", defaultSchema, fullParams)
 
 	instance.m.Lock()
@@ -140,11 +145,6 @@ func (instance *Instance) CachedConnectionPool(defaultSchema, params string) (*s
 	return db, err
 }
 
-// Connect is an alias for CachedConnectionPool.
-func (instance *Instance) Connect(defaultSchema string, params string) (*sqlx.DB, error) {
-	return instance.CachedConnectionPool(defaultSchema, params)
-}
-
 func (instance *Instance) rawConnectionPool(defaultSchema, fullParams string, alreadyLocked bool) (*sqlx.DB, error) {
 	fullDSN := fmt.Sprintf("%s%s?%s", instance.BaseDSN, defaultSchema, fullParams)
 	db, err := sqlx.Connect(instance.Driver, fullDSN)
@@ -213,6 +213,7 @@ func (instance *Instance) CloseAll() {
 		db.Close()
 		delete(instance.connectionPool, key)
 	}
+	instance.valid = false // force future conns to re-hydrate vars
 	instance.m.Unlock()
 }
 
@@ -220,7 +221,12 @@ func (instance *Instance) CloseAll() {
 // distribution/fork/vendor as well as major and minor version. If this is
 // unable to be determined or an error occurs, FlavorUnknown will be returned.
 func (instance *Instance) Flavor() Flavor {
-	instance.Valid() // force an attempt to hydrate flavor, if not done already
+	// Attempt to hydrate flavor, unless it was already done OR explicitly forced
+	// via ForceFlavor. (This call pattern differs slightly from other hydrated
+	// fields, since other fields don't have a notion of forcing an override value.)
+	if instance.flavor == FlavorUnknown {
+		instance.Valid()
+	}
 	return instance.flavor
 }
 
@@ -272,6 +278,15 @@ func (instance *Instance) LockWaitTimeout() int {
 	return instance.lockWaitTimeout
 }
 
+// SQLMode returns the full session-level sql_mode string for connections
+// using default parameters, or a blank string if it could not be queried.
+func (instance *Instance) SQLMode() string {
+	if ok, _ := instance.Valid(); !ok {
+		return ""
+	}
+	return strings.Join(instance.sqlMode, ",")
+}
+
 // hydrateVars populates several non-exported Instance fields by querying
 // various global and session variables. Failures are ignored; these variables
 // are designed to help inform behavior but are not strictly mandatory.
@@ -309,7 +324,10 @@ func (instance *Instance) hydrateVars(db *sqlx.DB, lock bool) {
 		return
 	}
 	instance.valid = true
-	instance.flavor = IdentifyFlavor(result.Version, result.VersionComment)
+	if instance.flavor == FlavorUnknown {
+		// Only set flavor if it wasn't already forced to some value
+		instance.flavor = IdentifyFlavor(result.Version, result.VersionComment)
+	}
 	instance.sqlMode = strings.Split(result.SQLMode, ",")
 	instance.waitTimeout = result.WaitTimeout
 	instance.lockWaitTimeout = result.LockWaitTimeout
@@ -328,13 +346,23 @@ func (instance *Instance) hydrateVars(db *sqlx.DB, lock bool) {
 // MariaDB 10.5+ as per https://jira.mariadb.org/browse/MDEV-21957; note the
 // space in the name (not to be confused with BINLOG_ADMIN with an underscore,
 // which is a MySQL 8.0 privilege which does NOT control sql_log_bin!)
-var reSkipBinlog = regexp.MustCompile(`(?:ALL PRIVILEGES ON \*\.\*|SUPER|SESSION_VARIABLES_ADMIN|SYSTEM_VARIABLES_ADMIN|BINLOG ADMIN)[,\s]`)
+// Meanwhile MariaDB 11.0 weakens SUPER to no longer confer fine-grained privs.
+var (
+	reSkipBinlog         = regexp.MustCompile(`(?:ALL PRIVILEGES ON \*\.\*|SUPER|SESSION_VARIABLES_ADMIN|SYSTEM_VARIABLES_ADMIN|BINLOG ADMIN)[,\s]`)
+	reSkipBinlogMaria110 = regexp.MustCompile(`(?:ALL PRIVILEGES ON \*\.\*|BINLOG ADMIN)[,\s]`)
+)
 
 // CanSkipBinlog returns true if instance.User has privileges necessary to
 // set sql_log_bin=0. If an error occurs in checking grants, this method returns
 // false as a safe fallback.
 func (instance *Instance) CanSkipBinlog() bool {
-	return instance.checkGrantsRegexp(reSkipBinlog)
+	var re *regexp.Regexp
+	if instance.Flavor().MinMariaDB(11, 0) {
+		re = reSkipBinlogMaria110
+	} else {
+		re = reSkipBinlog
+	}
+	return instance.checkGrantsRegexp(re)
 }
 
 func (instance *Instance) checkGrantsRegexp(re *regexp.Regexp) bool {
@@ -538,7 +566,7 @@ func (instance *Instance) introspectionParams() string {
 
 	// In MySQL 8, ensure we get up-to-date values for table sizes as well as next
 	// auto_increment value
-	if flavor.Min(FlavorMySQL80) {
+	if flavor.MinMySQL(8) {
 		v.Set("information_schema_stats_expiry", "0")
 	}
 
@@ -552,20 +580,14 @@ func (instance *Instance) introspectionParams() string {
 	//   collation; we must reparse from SHOW CREATE TABLE
 	// * In MariaDB, SHOW CREATE TABLE does not return 4-byte chars correctly
 	//   regardless of collation
-	if flavor.Min(FlavorMySQL57) {
+	if flavor.MinMySQL(5, 7) {
 		v.Set("collation", "binary")
 	}
 
-	keepMode := make([]string, 0, len(instance.sqlMode))
-	for _, mode := range instance.sqlMode {
-		// Strip out these problematic modes: ANSI, ANSI_QUOTES, NO_FIELD_OPTIONS, NO_KEY_OPTIONS, NO_TABLE_OPTIONS
-		if strings.HasPrefix(mode, "ANSI") || (strings.HasPrefix(mode, "NO_") && strings.HasSuffix(mode, "_OPTIONS")) {
-			continue
-		}
-		keepMode = append(keepMode, mode)
-	}
-	if len(keepMode) != len(instance.sqlMode) {
-		v.Set("sql_mode", fmt.Sprintf("'%s'", strings.Join(keepMode, ",")))
+	// Remove any problematic sql_mode values
+	keepModes := filterSQLMode(instance.sqlMode, IntrospectionBadSQLModes)
+	if len(keepModes) != len(instance.sqlMode) {
+		v.Set("sql_mode", fmt.Sprintf("'%s'", strings.Join(keepModes, ",")))
 	}
 
 	return v.Encode()
@@ -617,7 +639,7 @@ func tableHasRows(db *sqlx.DB, schema, table string) (bool, error) {
 	var result []int
 	query := fmt.Sprintf("SELECT 1 FROM %s.%s LIMIT 1", EscapeIdentifier(schema), EscapeIdentifier(table))
 	if err := db.Select(&result, query); err != nil {
-		return true, err
+		return true, fmt.Errorf("Error checking if table %s.%s is empty: %w", EscapeIdentifier(schema), EscapeIdentifier(table), err)
 	}
 	return len(result) != 0, nil
 }
@@ -698,22 +720,25 @@ func (instance *Instance) DropSchema(schema string, opts BulkDropOptions) error
 		return err
 	}
 
-	// No need to actually obtain the fully hydrated schema value; we already know
-	// it has no tables after the call above, and the schema's name alone is
-	// sufficient to call Schema.DropStatement() to generate the necessary SQL
-	s := &Schema{
-		Name: schema,
-	}
 	db, err := instance.CachedConnectionPool("", opts.params())
 	if err != nil {
-		return err
+		return fmt.Errorf("Error obtaining connection pool for dropping empty schema %s: %w", EscapeIdentifier(schema), err)
+	}
+
+	// Now that the tables have been removed, we can drop the schema without
+	// risking a long lock impacting the DB negatively
+	err = dropSchema(db, schema)
+	if IsDatabaseError(err, mysqlerr.ER_LOCK_WAIT_TIMEOUT) {
+		// we do 1 retry upon seeing a metadata locking conflict, consistent with
+		// logic in DropTablesInSchema
+		err = dropSchema(db, schema)
 	}
-	_, err = db.Exec(s.DropStatement())
 	if err != nil {
 		return err
 	}
 
-	prefix := fmt.Sprintf("%s?", schema)
+	// Close any connection pools for that database name
+	prefix := schema + "?"
 	instance.m.Lock()
 	defer instance.m.Unlock()
 	for key, connPool := range instance.connectionPool {
@@ -725,6 +750,17 @@ func (instance *Instance) DropSchema(schema string, opts BulkDropOptions) error
 	return nil
 }
 
+// dropSchema executes a DROP DATABASE on the supplied database name. This isn't
+// exported directly because it is unsafe to drop things in this manner in
+// production, as it holds locks for a long time if many tables are present.
+func dropSchema(db *sqlx.DB, schema string) error {
+	_, err := db.Exec("DROP DATABASE " + EscapeIdentifier(schema))
+	if err != nil {
+		return fmt.Errorf("Error dropping database %s: %w", EscapeIdentifier(schema), err)
+	}
+	return nil
+}
+
 // AlterSchema changes the character set and/or collation of the supplied schema
 // on instance. Supply an empty string for opts.DefaultCharSet to only change
 // the collation, or supply an empty string for opts.DefaultCollation to use the
@@ -781,9 +817,31 @@ func (opts BulkDropOptions) Concurrency() int {
 // DropTablesInSchema drops all tables in a schema. If opts.OnlyIfEmpty==true,
 // returns an error if any of the tables have any rows.
 func (instance *Instance) DropTablesInSchema(schema string, opts BulkDropOptions) error {
-	db, err := instance.CachedConnectionPool(schema, opts.params())
+	// We can normally execute multiple DROP TABLEs concurrently, which improves
+	// performance over a slow network link (WAN / VPN) even though the server
+	// actually runs them serially. However, if the flavor doesn't have optimized
+	// DROP TABLE, each drop is slow with a large-ish buffer pool, and having all
+	// those drops queued up will cause a stall (since no other queries will be
+	// able to run in between them). So in that case, reduce concurrency to 1.
+	concurrency := opts.Concurrency()
+	if instance.bufferPoolSize >= (32*1024*1024*1024) && !instance.Flavor().MinMySQL(8, 0, 23) {
+		concurrency = 1
+	}
+
+	// In MariaDB 10.6+, concurrent DROP TABLE can result in *InnoDB* locking
+	// conflicts if foreign keys are in-use. This causes a stall which isn't
+	// resolved until hitting innodb_lock_wait_timeout, which defaults to 50sec,
+	// longer than our default query timeout. See MDEV-32899 and MDEV-32883. To
+	// resolve this, we use a 3sec innodb_lock_wait_timeout and retry failures
+	// serially.
+	params := opts.params()
+	if concurrency > 1 && instance.Flavor().MinMariaDB(10, 6) {
+		params += "&innodb_lock_wait_timeout=3"
+	}
+
+	db, err := instance.CachedConnectionPool(schema, params)
 	if err != nil {
-		return err
+		return fmt.Errorf("Error obtaining connection pool for dropping tables in schema %s: %w", EscapeIdentifier(schema), err)
 	}
 
 	// Obtain table and partition names
@@ -811,40 +869,36 @@ func (instance *Instance) DropTablesInSchema(schema string, opts BulkDropOptions
 		}
 	}
 
-	// If buffer pool is over 32GB and flavor doesn't have optimized DROP TABLE,
-	// reduce drop concurrency to 1 to reduce risk of stalls
-	concurrency := opts.Concurrency()
-	if instance.bufferPoolSize >= (32*1024*1024*1024) && !instance.flavor.Min(FlavorMySQL80.Dot(23)) {
-		concurrency = 1
-	}
 	g, ctx := errgroup.WithContext(context.Background())
 	g.SetLimit(concurrency)
 	retries := make(chan string, len(tableMap))
 	for name, partitions := range tableMap {
 		name, partitions := name, partitions // avoid closure with loop iteration variables
-		g.Go(func() (err error) {
+		g.Go(func() error {
 			if len(partitions) > 1 && opts.PartitionsFirst {
-				err = dropPartitions(db, name, partitions[0:len(partitions)-1])
-			}
-			if err == nil {
-				_, err = db.ExecContext(ctx, "DROP TABLE "+EscapeIdentifier(name))
-				// With the new data dictionary added in MySQL 8.0, attempting to
-				// concurrently drop two tables that have a foreign key constraint between
-				// them can deadlock, so we try them serially later. Metadata lock timeouts
-				// are also more common with FKs in MySQL 8.0, so we retry those as well.
-				if IsDatabaseError(err, mysqlerr.ER_LOCK_DEADLOCK, mysqlerr.ER_LOCK_WAIT_TIMEOUT) {
-					retries <- name
-					err = nil
+				if err := dropPartitions(db, name, partitions[0:len(partitions)-1]); err != nil {
+					return err
 				}
 			}
-			return err
+			_, err := db.ExecContext(ctx, "DROP TABLE "+EscapeIdentifier(name))
+			if IsDatabaseError(err, mysqlerr.ER_LOCK_DEADLOCK, mysqlerr.ER_LOCK_WAIT_TIMEOUT) {
+				// If foreign keys are being used, DROP TABLE can encounter lock wait
+				// timeouts in various situations in MySQL 8.0+ or MariaDB 10.6+, due to
+				// concurrent drops or due to cross-schema FKs. MySQL 8.0+ can also
+				// encounter deadlocks due to concurrent drops.
+				// We retry these failed drops later in a serial manner.
+				retries <- name
+			} else if err != nil {
+				return fmt.Errorf("Error dropping table %s.%s: %w", EscapeIdentifier(schema), EscapeIdentifier(name), err)
+			}
+			return nil
 		})
 	}
 	fatalErr := g.Wait()
 	close(retries)
 	for name := range retries {
 		if _, err := db.Exec("DROP TABLE " + EscapeIdentifier(name)); err != nil {
-			return err
+			return fmt.Errorf("Error dropping table %s.%s even after retry: %w", EscapeIdentifier(schema), EscapeIdentifier(name), err)
 		}
 	}
 	return fatalErr
@@ -924,7 +978,7 @@ func tablesToPartitions(db *sqlx.DB, schema string, flavor Flavor) (map[string][
 		WHERE    p.table_schema = ?
 		ORDER BY p.table_name, p.partition_ordinal_position`
 	if err := db.Select(&rawNames, query, schema); err != nil {
-		return nil, err
+		return nil, fmt.Errorf("Error querying information_schema.partitions: %w", err)
 	}
 
 	var checkViews bool
@@ -949,14 +1003,14 @@ func tablesToPartitions(db *sqlx.DB, schema string, flavor Flavor) (map[string][
 
 	// MySQL 8's new data dictionary actually includes views in
 	// information_schema.partitions, so remove them explicitly.
-	if checkViews && flavor.Min(FlavorMySQL80) {
+	if checkViews && flavor.MinMySQL(8) {
 		var viewNames []string
 		query := `
 				SELECT table_name
 				FROM   information_schema.views
 				WHERE  table_schema = ?`
 		if err := db.Select(&viewNames, query, schema); err != nil {
-			return nil, err
+			return nil, fmt.Errorf("Error querying information_schema.views: %w", err)
 		}
 		for _, name := range viewNames {
 			delete(partitions, name)
@@ -972,14 +1026,14 @@ func dropPartitions(db *sqlx.DB, table string, partitions []string) error {
 			EscapeIdentifier(table),
 			EscapeIdentifier(partName)))
 		if err != nil {
-			return err
+			return fmt.Errorf("Error dropping partition of table %s: %w", EscapeIdentifier(table), err)
 		}
 	}
 	return nil
 }
 
 // DefaultCharSetAndCollation returns the instance's default character set and
-// collation
+// collation.
 func (instance *Instance) DefaultCharSetAndCollation() (serverCharSet, serverCollation string, err error) {
 	db, err := instance.CachedConnectionPool("", "")
 	if err != nil {
@@ -988,3 +1042,60 @@ func (instance *Instance) DefaultCharSetAndCollation() (serverCharSet, serverCol
 	err = db.QueryRow("SELECT @@global.character_set_server, @@global.collation_server").Scan(&serverCharSet, &serverCollation)
 	return
 }
+
+// ServerProcess describes the status of a connection on an Instance.
+type ServerProcess struct {
+	ID      int64
+	User    string
+	Schema  string
+	Command string
+	Time    float64
+	State   string
+	Info    string
+}
+
+// ProcessList returns the current list of connections on instance. This is
+// primarily intended for debugging and test output at this time, and may be
+// disruptive on live production database servers, especially on MySQL 8.0+.
+func (instance *Instance) ProcessList() (plist []ServerProcess, err error) {
+	var db *sqlx.DB
+	db, err = instance.CachedConnectionPool("", "")
+	if err != nil {
+		return
+	}
+	var query string
+	if instance.Flavor().IsMariaDB() {
+		query = "SELECT Id, User, db, Command, Time, time_ms, State, Info FROM information_schema.processlist"
+	} else {
+		// TODO this should use a different approach on recent MySQL releases
+		query = "SHOW PROCESSLIST"
+	}
+	var raw []struct {
+		ID        int64          `db:"Id"`
+		User      string         `db:"User"`
+		Schema    sql.NullString `db:"db"`
+		Command   string         `db:"Command"`
+		TimeInt   uint64         `db:"Time"`
+		TimeFloat float64        `db:"time_ms"`
+		State     sql.NullString `db:"State"`
+		Info      sql.NullString `db:"Info"`
+	}
+	err = db.Select(&raw, query)
+	for _, p := range raw {
+		sp := ServerProcess{
+			ID:      p.ID,
+			User:    p.User,
+			Schema:  p.Schema.String,
+			Command: p.Command,
+			Time:    p.TimeFloat / 1000.0,
+			State:   p.State.String,
+			Info:    p.Info.String,
+		}
+		// Only MariaDB provides fractional time
+		if p.TimeInt >= 1 && sp.Time < 1.0 {
+			sp.Time = float64(p.TimeInt)
+		}
+		plist = append(plist, sp)
+	}
+	return
+}
