@@ -3,14 +3,21 @@ package workspace
 import (
 	"errors"
 	"fmt"
+	"net/url"
 	"strings"
 	"sync"
 
+	"github.com/VividCortex/mysqlerr"
 	"github.com/jmoiron/sqlx"
 	log "github.com/sirupsen/logrus"
 	"github.com/skeema/skeema/internal/tengo"
 )
 
+// On arm64, we must supply an exact patch number in the image tag for Percona
+// Server 8.0. There is no "latest" nor "8.0" tag for arm64. For now we always
+// plug in a specific recent patch release to solve this.
+const latestPercona80Patch = "36"
+
 // LocalDocker is a Workspace created inside of a Docker container on localhost.
 // The schema is dropped when done interacting with the workspace in Cleanup(),
 // but the container remains running. The container may optionally be stopped
@@ -31,8 +38,14 @@ var cstore struct {
 // NewLocalDocker finds or creates a containerized MySQL instance, creates a
 // temporary schema on it, and returns it.
 func NewLocalDocker(opts Options) (_ *LocalDocker, retErr error) {
-	if !opts.Flavor.Supported() {
-		return nil, fmt.Errorf("NewLocalDocker: unsupported flavor %s", opts.Flavor)
+	// Return an error if no flavor was supplied; otherwise log a warning if the
+	// supplied flavor looks problematic
+	if opts.Flavor == tengo.FlavorUnknown {
+		return nil, errors.New("no flavor supplied")
+	} else if !opts.Flavor.Known() {
+		log.Warnf("Flavor %s is not fully supported, and may not work properly with workspace=docker", opts.Flavor)
+	} else if opts.Flavor.TooNew() {
+		log.Warnf("Flavor %s is newer than this release of Skeema, and may not work properly with workspace=docker", opts.Flavor)
 	}
 
 	// NewLocalDocker names its error return so that a deferred func can check if
@@ -55,26 +68,38 @@ func NewLocalDocker(opts Options) (_ *LocalDocker, retErr error) {
 		defaultConnParams: opts.DefaultConnParams,
 	}
 
-	image := opts.Flavor.String()
-	if arch, err := tengo.DockerEngineArchitecture(); err != nil {
+	// Determine image and container name
+	arch, err := tengo.DockerEngineArchitecture()
+	if err != nil {
 		return nil, err
-	} else if arch == "arm64" && opts.Flavor.IsMySQL() {
-		// MySQL 8.0.29+ images are available for arm64 on DockerHub via _/mysql;
-		// for older MySQL 8 versions we must use mysql/mysql-server instead.
-		// Pre-8 MySQL, or any version of Percona Server, are not available.
-		if opts.Flavor.Min(tengo.FlavorMySQL80) && opts.Flavor.Variants == tengo.VariantNone {
-			if opts.Flavor.Version[2] >= 12 && opts.Flavor.Version[2] < 29 {
-				image = strings.Replace(image, "mysql:", "mysql/mysql-server:", 1)
-			}
-		} else {
-			log.Warnf("Official arm64 Docker images for %s are not available. Substituting mysql:8.0 instead for workspace purposes, which may cause behavior differences.", image)
-			opts.ContainerName = strings.Replace(opts.ContainerName, tengo.ContainerNameForImage(image), "mysql-8.0", 1)
-			image = "mysql:8.0"
+	}
+	image, err := DockerImageForFlavor(opts.Flavor, arch)
+	if err != nil {
+		log.Warn(err.Error() + ". Substituting mysql:8.0 instead for workspace purposes, which may cause behavior differences.")
+		image = "mysql:8.0"
+
+		// If the original requested flavor was MySQL 5.x, force session-level
+		// default_collation_for_utf8mb4=utf8mb4_general_ci so that any usage of
+		// utf8mb4 without an explicit collation clause will behave like it did in
+		// 5.x. The MySQL Manual warns against setting this, but it works successfully
+		// at the session level in all versions of 8.0; and our motivation here is
+		// conceptually similar to the logical replication use-case that this variable
+		// was introduced to handle.
+		if opts.Flavor.IsMySQL(5) {
+			ld.defaultConnParams += "&default_collation_for_utf8mb4=utf8mb4_general_ci"
+			ld.defaultConnParams = strings.TrimPrefix(ld.defaultConnParams, "&")
 		}
 	}
 	if opts.ContainerName == "" {
 		opts.ContainerName = "skeema-" + tengo.ContainerNameForImage(image)
+	} else if image != opts.Flavor.String() { // attempt to fix user-supplied name if we had to adjust the image
+		oldName := tengo.ContainerNameForImage(opts.Flavor.String())
+		newName := tengo.ContainerNameForImage(image)
+		if oldName != newName {
+			opts.ContainerName = strings.Replace(opts.ContainerName, oldName, newName, 1)
+		}
 	}
+
 	if cstore.containers[opts.ContainerName] != nil {
 		ld.d = cstore.containers[opts.ContainerName]
 	} else {
@@ -159,8 +184,29 @@ func (ld *LocalDocker) ConnectionPool(params string) (*sqlx.DB, error) {
 	// different sibling subdirectories with differing configurations).
 	// So, here we must merge the params arg (callsite-dependent) over top of the
 	// LocalDocker params (dir-dependent).
-	finalParams := tengo.MergeParamStrings(ld.defaultConnParams, params)
-	return ld.d.CachedConnectionPool(ld.schemaName, finalParams)
+	// We also forcibly disable tls in a way which cannot be overridden, since the
+	// Docker container is local.
+	finalParams := tengo.MergeParamStrings(ld.defaultConnParams, params, "tls=false")
+	db, err := ld.d.CachedConnectionPool(ld.schemaName, finalParams)
+
+	// In the rare situation where OptionsForDir obtained sql_mode from a live
+	// instance of different flavor than our Docker image's flavor, connections may
+	// hit Error 1231 (42000): Variable 'sql_mode' can't be set to the value ...
+	// This can happen if overriding flavor on the command-line, or even
+	// automatically if the real server runs 5.7 but local machine is ARM.
+	// In this case, try conn again with all non-portable sql_mode values removed.
+	if tengo.IsDatabaseError(err, mysqlerr.ER_WRONG_VALUE_FOR_VAR) && strings.Contains(finalParams, "sql_mode") {
+		v, _ := url.ParseQuery(finalParams)
+		sqlMode := v.Get("sql_mode")
+		if len(sqlMode) > 1 {
+			sqlMode = sqlMode[1 : len(sqlMode)-1] // strip leading/trailing single-quotes
+			v.Set("sql_mode", "'"+tengo.FilterSQLMode(sqlMode, tengo.NonPortableSQLModes)+"'")
+			finalParams = v.Encode()
+			db, err = ld.d.CachedConnectionPool(ld.schemaName, finalParams)
+		}
+	}
+
+	return db, err
 }
 
 // IntrospectSchema introspects and returns the temporary workspace schema.
@@ -222,3 +268,77 @@ func (ld *LocalDocker) shutdown(args ...interface{}) bool {
 	delete(cstore.containers, ld.d.ContainerName())
 	return true
 }
+
+// DockerImageForFlavor attempts to return the name of a Docker image for the
+// supplied flavor and arch. The arch should be supplied in the same format as
+// returned by tengo.DockerEngineArchitecture(), i.e. "amd64" or "arm64".
+// In most cases this function returns "Docker official" Dockerhub images (top-
+// level repos without an account name), but in some cases we must use a
+// different source, or return an error.
+func DockerImageForFlavor(flavor tengo.Flavor, arch string) (string, error) {
+	image := flavor.String()
+
+	// flavor is often supplied with a zero patch value to mean "latest patch" in
+	// terms of Docker images, for example the config "flavor=mysql:8.0" means we
+	// want the latest 8.0.X version. To ensure we can use these values in methods
+	// like tengo.Flavor.MinMySQL() properly, convert 0 to the highest value.
+	// (since flavor is passed by value, this won't affect the caller.)
+	var wantLatest bool
+	if flavor.Version[2] == 0 {
+		flavor.Version[2] = 65535
+		wantLatest = true
+	}
+
+	// Percona 8.1+ on any arch, or 8.0.33+ on arm64: use percona/percona-server.
+	// On arm64 we MUST include a patch value AND also add a "-aarch64" suffix to
+	// the tag, as there is no "latest" nor "8.0" tag for arm64. For now we always
+	// plug in a specific recent patch release in place of 8.0.
+	// Below 8.0.33, Percona images for arm64 are not available at all.
+	if flavor.IsPercona() {
+		if flavor.MinMySQL(8, 1) || arch == "arm64" {
+			image = strings.Replace(image, "percona:", "percona/percona-server:", 1)
+		}
+		if arch == "arm64" {
+			if !flavor.MinMySQL(8, 0, 33) {
+				return "", fmt.Errorf("%s Docker images for %s are not available", arch, image)
+			}
+			if strings.HasSuffix(image, ":8.0") {
+				image += "." + latestPercona80Patch + "-aarch64"
+			} else if wantLatest {
+				image += ".0-aarch64"
+			} else {
+				image += "-aarch64"
+			}
+		}
+		return image, nil
+	}
+
+	// Aurora flavors from Skeema Premium: use corresponding MySQL image, but
+	// without any patch version for 5.X.Y since Aurora historically used very
+	// low patch versions.
+	// This chunk intentionally doesn't return early! It is designed to fall
+	// through to the regular MySQL logic below it.
+	if flavor.IsAurora() {
+		if strings.HasPrefix(image, "aurora:5.6.") {
+			image = "mysql:5.6"
+		} else if strings.HasPrefix(image, "aurora:5.7.") {
+			image = "mysql:5.7"
+		} else {
+			image = strings.Replace(image, "aurora:", "mysql:", 1)
+		}
+	}
+
+	// MySQL on arm64: use mysql/mysql-server for 8.0.12-8.0.28.
+	// Below 8.0.12 (incl all 5.x), arm64 MySQL images are not available at all.
+	if arch == "arm64" && flavor.IsMySQL() {
+		if !flavor.MinMySQL(8, 0, 12) {
+			return "", fmt.Errorf("%s Docker images for %s are not available", arch, image)
+		} else if !flavor.MinMySQL(8, 0, 29) {
+			return strings.Replace(image, "mysql:", "mysql/mysql-server:", 1), nil
+		}
+		return image, nil
+	}
+
+	// All other situations: return image from flavor string as-is
+	return image, nil
+}
