@@ -3,8 +3,8 @@ package workspace
 import (
 	"errors"
 	"fmt"
-	"os"
 	"strings"
+	"testing"
 
 	"github.com/jmoiron/sqlx"
 	"github.com/skeema/skeema/internal/tengo"
@@ -46,7 +46,9 @@ func NewTempSchema(opts Options) (_ *TempSchema, retErr error) {
 
 	lockName := fmt.Sprintf("skeema.%s", ts.schemaName)
 	if ts.releaseLock, err = getLock(ts.inst, lockName, opts.LockTimeout); err != nil {
-		return nil, fmt.Errorf("Unable to lock temporary schema on %s: %s", ts.inst, err)
+		return nil, fmt.Errorf("Unable to lock temp-schema workspace on %s: %s\n"+
+			"Usually this means another copy of Skeema is already holding the lock and operating on this database server. If you are certain that your operation will not conflict, try supplying a different name for --temp-schema on the command-line.",
+			ts.inst, err)
 	}
 
 	// If NewTempSchema errors, don't continue to hold the lock
@@ -60,9 +62,9 @@ func NewTempSchema(opts Options) (_ *TempSchema, retErr error) {
 	// which means the TempSchema may not be fully isolated from non-workspace
 	// workloads and their own usage of metadata locks. As a result, we must force
 	// a low lock_wait_timeout on any TempSchema DDL in MySQL 8.
-	if ts.inst.Flavor().Min(tengo.FlavorMySQL80) {
+	if ts.inst.Flavor().MinMySQL(8) {
 		wantLockWait := 5
-		if strings.HasSuffix(os.Args[0], ".test") || strings.HasSuffix(os.Args[0], ".test.exe") {
+		if testing.Testing() {
 			wantLockWait = 2 // use lower value in test suites so MDL-related tests aren't super slow
 		}
 		if ts.inst.LockWaitTimeout() > wantLockWait {
@@ -110,7 +112,7 @@ func (ts *TempSchema) bulkDropOptions() tengo.BulkDropOptions {
 // workspace schema, using the supplied connection params (which may be blank).
 func (ts *TempSchema) ConnectionPool(params string) (*sqlx.DB, error) {
 	if ts.mdlTimeout > 0 && !strings.Contains(params, "lock_wait_timeout") {
-		params = strings.TrimLeft(fmt.Sprintf("%s&lock_wait_timeout=%d", params, ts.mdlTimeout), "&")
+		params = tengo.MergeParamStrings(params, fmt.Sprintf("lock_wait_timeout=%d", ts.mdlTimeout))
 	}
 	return ts.inst.CachedConnectionPool(ts.schemaName, params)
 }
